@@ -7,7 +7,7 @@ get_coef_names <- function(Mlist, K) {
   coefs <- rbind(
     if (!is.null(Mlist$Xc))
       cbind(paste0("beta[", K["Xc", 1]:K["Xc", 2], "]"),
-            colnames(Mlist$Xc)),
+            colnames(Mlist$Xc)[K["Xc", 1]:K["Xc", 2]]),
     if (!is.null(Mlist$Xic))
       cbind(paste0("beta[", K["Xic", 1]:K["Xic", 2], "]"),
             colnames(Mlist$Xic)),
@@ -30,6 +30,9 @@ get_coef_names <- function(Mlist, K) {
       cbind(paste0("beta[", K["Xil", 1]:K["Xil", 2], "]"),
             colnames(Mlist$Xil))
   )
+  if (max(K, na.rm = TRUE) == 1) { # case with only intercept
+    coefs[, 1] <- gsub('beta\\[1\\]', 'beta', coefs[, 1])
+  }
 
   return(coefs)
 }
